@@ -1,2 +1,2 @@
-from math_x import *
+from . import math_x
 # __all__ = ["math_x"]
